@@ -28,10 +28,12 @@ describe 'basic manila' do
       }
 
       # Manila resources
+      class { '::manila::logging':
+        debug => true,
+      }
       class { '::manila':
         default_transport_url => 'rabbit://manila:an_even_bigger_secret@127.0.0.1:5672/',
         sql_connection        => 'mysql+pymysql://manila:a_big_secret@127.0.0.1/manila?charset=utf8',
-        debug                 => true,
       }
       class { '::manila::db::mysql':
         password => 'a_big_secret',
@@ -47,7 +49,13 @@ describe 'basic manila' do
       class { '::manila::keystone::authtoken':
         password => 'a_big_secret',
       }
-      class { '::manila::api': }
+      class { '::manila::api':
+        service_name        => 'httpd',
+      }
+      include ::apache
+      class { '::manila::wsgi::apache':
+        ssl => false,
+      }
       class { '::manila::scheduler': }
 
       # missing: backends, share, service_instance
@@ -60,7 +68,7 @@ describe 'basic manila' do
     end
 
     describe port(8786) do
-      it { is_expected.to be_listening.with('tcp') }
+      it { is_expected.to be_listening }
     end
 
   end
